@@ -522,14 +522,6 @@ class HumanPlay:
     def upon_episode_completion(self):
         save = tkinter.messagebox.askquestion("Save", "Episode ended - save the result?")
 
-        if not os.path.exists('results'):
-            os.makedirs('results')
-
-        tick = time.time()
-        filename = 'results/%s.json' % tick
-        with open(filename, 'w') as file_obj:
-            json.dump(self.data, file_obj)
-
         if save == 'yes':
             path = 'results/human_results' + '_' + self.user + '_' + self.session_id + '.csv'
             self.log_result(path)
@@ -544,6 +536,12 @@ class HumanPlay:
         if not os.path.exists('results'):
             os.makedirs('results')
 
+        tick = time.time()
+        savename = str(self.user) + '_' + str(tick)
+        filename = 'results/%s.json' % savename
+        with open(filename, 'w') as file_obj:
+            json.dump(self.data, file_obj)
+
         with open(path, 'a', newline='') as log_file:
             schema = ['user', 'env', 'game_mode', 'iou', 'reward', 'num_steps', 'num_bricks']
             writer = csv.DictWriter(log_file, fieldnames=schema)
